<?xml version="1.0" ?>
<xsl:stylesheet version="1.0"
      xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
      xmlns:xalan="http://xml.apache.org/xslt"
>
<xsl:import href="../html/htmlhead.xsl"/>
<xsl:import href="../css/maincss.xsl"/>
<xsl:import href="../html/htmlfoot.xsl"/>
<xsl:import href="excerpt.head.xsl"/>
<xsl:import  href="excerpt.head.js.xsl"/>
<xsl:import href="excerpt.content.items.xsl"/>

<xsl:output method="html" omit-xml-declaration="yes"  indent="yes" 
encoding="iso-8859-1" xalan:indent-amount="5" />

<xsl:param name="indexfile" />
<xsl:param name="excerptfile" />
<xsl:param name="excerptsrc" />
<xsl:param name="dest.home" />
<xsl:param name="src.home" />
<xsl:param name="backlink" />
<xsl:param name="backlabel" />
<xsl:param name="navbarfile" />

<!--
        @author                Peter Heibronn
        @description           this style sheet makes an excerpt html file

				!this is in respect to a two column representation! see the 'CommentHead' 
Item which is the only one item
				represented in the column

        @param                 indexfile      the path of the xml description 
file of the index with information about related link targets
        @param                 excerptfile    URL of the orginal XML excerpt
file itself
	@param		       excerptsrc     IndexItem/@src	as the id to get informations
	@param		       dest.home      URL of the root of html document tree
-->

<!--
	lookup several items and files to link to

-->
	<xsl:variable name="headlink2orig"><!-- is there an original file we will link
to it also-->
		<xsl:for-each select="document($indexfile)//IndexItem[@src=$excerptsrc and
count(@origdest)>0]">
				<xsl:value-of select="concat(@base,'/',@origdest)" />
				<xsl:message><xsl:value-of select="concat('headlink2orig:
',@base,'/',@origdest,':',position())" /> </xsl:message>
		</xsl:for-each>
	</xsl:variable>

	<xsl:variable name="link2orig"><!-- is the link mode on, we create Section
links to the original file too -->
		<xsl:for-each select="document($indexfile)//IndexItem[@src=$excerptsrc and
@origlinkmode='on']"><xsl:value-of select="$headlink2orig" />
		</xsl:for-each>
	</xsl:variable> 

	<xsl:variable name="navbarfilepath">
    	<xsl:value-of select="concat($src.home,'/',$navbarfile)" />
    </xsl:variable>

	<xsl:variable name="prev-image">
	<!-- xsl:message><xsl:value-of select="concat('-
',count(document($indexfile)//IndexItem[@src=$excerptsrc]))"/></xsl:message -->
		<xsl:if test="string-length($indexfile)>0">
		<xsl:value-of
select="concat(document($indexfile)//IndexItem[@src=$excerptsrc]/@base,'/',document($navbarfilepath)/Nav/NavParam[@name='prev-image']/@value)"
/></xsl:if>
	</xsl:variable>

	<xsl:variable name="home.link">
		<xsl:value-of select="document($navbarfilepath)/Nav/@site" />
	</xsl:variable>


	<xsl:variable name="link2conspect">
	<!-- is there an conspectus, we will link to it -->
			<xsl:for-each
select="document($indexfile)//IndexItem[@src=$excerptsrc]/DocInfo[@name='conspect']">
				<xsl:value-of select="concat(@base,'/',@dest)" />
			</xsl:for-each>
	</xsl:variable>


	<xsl:variable name="link2structure">
	<!-- is there an structure file, we will link to it -->
			<xsl:for-each
select="document($indexfile)//IndexItem[@src=$excerptsrc]/DocInfo[@name='structure']">
				<xsl:value-of select="concat(@base,'/',@dest)" />
			</xsl:for-each>
	</xsl:variable>


<xsl:variable name="itembase">
	<xsl:value-of select="document($indexfile)//IndexItem[@src=$excerptsrc]/@base"
/>
</xsl:variable>



<xsl:template match="/"><!-- because this file will be imported by several other


















stylesheets, we will call here explicitly the excerpt templates -->
	<xsl:apply-templates select="Excerpt|Notice" mode="excerpt" />
</xsl:template>



<xsl:template match="Excerpt|Notice" mode="excerpt" >
<xsl:message><xsl:value-of select="concat('Excerpt
(',@origdest,'#',$indexfile,', ',$excerptfile,', ',$excerptsrc,',
',$backlink,',',$prev-image ,')')" /></xsl:message>

<html>
	<head>
	<xsl:comment>DO NOT EDIT THIS FILE WAS CREATED WITH excerpt.xsl. </xsl:comment>
	 <xsl:call-template name="htmlhead">
		<xsl:with-param name="titleprefix" select="'MXKS'" />
	 </xsl:call-template>

<xsl:call-template name="maincss" />
<xsl:call-template name="excerpt.head.js"/>
</head>

  <body>
  <xsl:comment>Do not, edit this file was automaticaly created from the
excerpt.xsl .</xsl:comment>
  <!-- the top link -->
  <a name="top"></a>

  <!-- create the excerpt head -->
  <xsl:call-template name="excerpt.head">
	<xsl:with-param name="excerptsrc" select="$excerptsrc" />
        <xsl:with-param name="indexfile" select="$indexfile" />
	<xsl:with-param name="backlink" select="$backlink" />
	<xsl:with-param name="backlabel" select="$backlabel" />
	<xsl:with-param name="dest.home" select="$dest.home" />
	<xsl:with-param name="link2orig" select="$headlink2orig" />
	<xsl:with-param name="prev-image" select="$prev-image" />
	<xsl:with-param name="home.link" select="$home.link" />
  </xsl:call-template>

  <!-- create the index section -->
  <xsl:apply-templates select="Section" mode="index" />

  <!-- create the documents content -->
  <xsl:apply-templates select="Abstract" mode="content" />

  <xsl:apply-templates select="Section" mode="content">
		<xsl:with-param name="link2orig" select="$link2orig" />
		<xsl:with-param name="link2conspect" select="$link2conspect" />
  </xsl:apply-templates>

  <xsl:if test="count(P)>0">
  	<hr />
  	<xsl:apply-templates select="P" />
  </xsl:if>

  <xsl:call-template name="htmlfoot"/>

  </body>

</html>
</xsl:template>

<!-- ################################# index section
##################################















          -->
<xsl:template match="Section" mode="index">

<!-- compute the section index number -->
<xsl:variable name="secnumber">
	<!-- relate an fixed prefix is given -->
	<xsl:if test="count(@index)>0" >
		<xsl:value-of select="@index"/>
	</xsl:if>
	<xsl:if test="count(@index)=0" >
		<!-- an optional counting base is given -->
		<xsl:if test="count(@count)>0" >
			<xsl:number count="Section" format="1." level="single"
value="@count+position()"  />
		</xsl:if>
		<!-- using the normal kind of numbering -->
		<xsl:if test="count(@count)=0" >
			<xsl:number count="Section" format="1." level="single"/>
		</xsl:if>
	</xsl:if>
</xsl:variable>

<xsl:variable name="secnumber.index"><xsl:number count="Section" format="1." 
level="single"/></xsl:variable>

	<xsl:value-of select="concat($secnumber,' ')"/>
        <xsl:element name="a">
		<xsl:attribute name="style">text-decoration:none; color:black; 
margin-top:0.5em; margin-bottom:0.5em;</xsl:attribute>
                <xsl:attribute name="href"><xsl:value-of 
select="concat('#',$secnumber.index)"/></xsl:attribute>
		<xsl:attribute name="name"><xsl:value-of 
select="concat('Ix',$secnumber.index)"/></xsl:attribute>
		<xsl:attribute name="id"><xsl:value-of 
select="concat('Ix',$secnumber.index)"/></xsl:attribute>
                <xsl:value-of select="@title"/>
         </xsl:element>

	<xsl:choose>
	<xsl:when test="count(Subsection/*)>0">
		<blockquote>
			<xsl:apply-templates select="Subsection" mode="index">
				<xsl:with-param name="secnumber" select="$secnumber" />
			</xsl:apply-templates>
		</blockquote>
	</xsl:when>
	<xsl:otherwise>
                <br />
	</xsl:otherwise>
	</xsl:choose>

</xsl:template>

<xsl:template match="Subsection" mode="index">
	<xsl:param name="secnumber" />

<xsl:variable name="subsecnumber">
	<xsl:if test="count(@index)>0" >
		<xsl:value-of select="@index"/>
	</xsl:if>

	<xsl:if test="count(@index)=0" >
		<xsl:value-of select="$secnumber" />
		<!-- relate an fixed prefix is given -->
		<xsl:if test="count(@index)=0" >
			<!-- an optional counting base is given -->
			<xsl:if test="count(@count)>0" >
				<xsl:number count="Subsection" format="1.1.1.1." level="multiple"
value="@count+position()"  />
			</xsl:if>
			<!-- using the normal kind of numbering -->
			<xsl:if test="count(@count)=0" >
				<xsl:number count="Subsection" format="1.1.1.1." level="multiple"/>
			</xsl:if>
		</xsl:if>
	</xsl:if>
</xsl:variable>

<xsl:variable name="subsecnumber.index"><xsl:number count="Section|Subsection"
format="1.1.1." level="multiple"/></xsl:variable>
<!-- xsl:message><xsl:value-of select="$subsecnumber.index"/></xsl:message -->
 	<xsl:value-of select="concat($subsecnumber,' ')"/>
        <xsl:element name="a">
		<xsl:attribute name="style">text-decoration:none; color:black</xsl:attribute>
                <xsl:attribute name="href"><xsl:value-of
select="concat('#',$subsecnumber.index)"/></xsl:attribute>
		<xsl:attribute name="name"><xsl:value-of
select="concat('Ix',$subsecnumber.index)"/></xsl:attribute>
		<xsl:attribute name="id"><xsl:value-of
select="concat('Ix',$subsecnumber.index)"/></xsl:attribute>
                <xsl:value-of select="@title"/>
        </xsl:element>

	<xsl:choose>
	<xsl:when test="count(Subsection)>0">
		<blockquote>
			<xsl:apply-templates select="Subsection" mode="index">
				<xsl:with-param name="secnumber" select="$secnumber" />
			</xsl:apply-templates>
		</blockquote>
	</xsl:when>
	<xsl:otherwise>
                <br />
	</xsl:otherwise>
	</xsl:choose>

</xsl:template>

<!-- ################################# content section
#################################















       -->





<xsl:template match="Section" mode="content">
<!-- compute the section index number -->
<xsl:variable name="secnumber">
	<!-- relate an fixed prefix is given -->
	<xsl:if test="count(@index)>0" >
		<xsl:value-of select="@index"/>
	</xsl:if>
	<xsl:if test="count(@index)=0" >
		<!-- an optional counting base is given -->
		<xsl:if test="count(@count)>0" >
			<xsl:number count="Section" format="1." level="single"
value="@count+position()"  />
		</xsl:if>
		<!-- using the normal kind of numbering -->
		<xsl:if test="count(@count)=0" >
			<xsl:number count="Section" format="1." level="single"/>
		</xsl:if>
	</xsl:if>
</xsl:variable>

<xsl:variable name="secnumber.index"><xsl:number count="Section" format="1." 
level="single"/></xsl:variable>


	<hr />
<p>
<xsl:value-of select="concat($secnumber,' ')"/>
<xsl:element name="a">
                <xsl:attribute 
name="href"><xsl:text>#top</xsl:text></xsl:attribute>
		<xsl:attribute name="style">color:black; font-size:1.3em</xsl:attribute>
		<xsl:attribute name="name"><xsl:value-of 
select="$secnumber.index"/></xsl:attribute>
		<xsl:attribute name="id"><xsl:value-of 
select="$secnumber.index"/></xsl:attribute>
                <xsl:value-of select="@title"/>
</xsl:element>

<xsl:if test="string-length($link2conspect)>0" ><!-- create link to the 
excerptfile if it exits-->
	<xsl:element name="a">
		<xsl:attribute name="style">color:blue; text-decoration:none; 
font-size:0.7em;</xsl:attribute>
		<xsl:attribute name="href"><xsl:value-of 
select="concat($link2conspect,'#',$secnumber.index)"/></xsl:attribute>(&#187; 
K)</xsl:element>
</xsl:if>

<xsl:if test="string-length($link2orig)>0" ><!-- create link to the excerptfile 
if it exits-->
	<xsl:element name="a">
		<xsl:attribute name="style">color:red; text-decoration:none; 
font-size:0.7em;</xsl:attribute>
		<xsl:attribute name="href"><xsl:value-of 
select="concat($link2orig,'#',$secnumber.index)"/></xsl:attribute>(&#187; 
O)</xsl:element>
</xsl:if>
</p>
	<xsl:apply-templates>
		<xsl:with-param name="sectionanchor" select="$secnumber.index" />
		<xsl:with-param name="secnumber" select="$secnumber" />
	</xsl:apply-templates>
</xsl:template>

<!-- ################################# Subsection -->
<xsl:template match="Subsection">
	<xsl:param name="sectionanchor" />
	<xsl:param name="secnumber" />
<!-- xsl:variable name="subsecnumber"><xsl:number 
count="Section|Subsection|Subsection" format="1.1.1." 
level="multiple"/></xsl:variable -->
<xsl:variable name="subsecnumber">
	<xsl:if test="count(@index)>0" >
		<xsl:value-of select="@index"/>
	</xsl:if>
	<xsl:if test="count(@index)=0" >
		<!-- relate an fixed prefix is given -->
		<xsl:value-of select="$secnumber" />
		<!-- an optional counting base is given -->
		<xsl:if test="count(@count)>0" >
			<xsl:number count="Subsection" format="1.1.1.1." level="multiple" 
value="@count+position()"  />
		</xsl:if>
		<!-- using the normal kind of numbering -->
		<xsl:if test="count(@count)=0" >
			<xsl:number count="Subsection" format="1.1.1.1." level="multiple"/>
		</xsl:if>
	</xsl:if>
</xsl:variable>

<xsl:variable name="subsecnumber.index"><xsl:number count="Section|Subsection"
format="1.1.1." level="multiple"/></xsl:variable>

<p>
<xsl:value-of select="concat($subsecnumber,' ')"/>
<xsl:element name="a"><!-- link back to the content section, and anchor with 
absolute subsection -->
		<xsl:attribute name="style">color:black; font-size:1.2em</xsl:attribute>
                <xsl:attribute name="href"><xsl:value-of 
select="concat('#',$sectionanchor)"/></xsl:attribute>
		<xsl:attribute name="name"><xsl:value-of 
select="$subsecnumber.index"/></xsl:attribute>
		<xsl:attribute name="id"><xsl:value-of 
select="$subsecnumber.index"/></xsl:attribute>
                <xsl:value-of select="@title"/>
</xsl:element>

<xsl:if test="string-length($link2conspect)>0" ><!-- create link to the 
excerptfile if it exits-->
	<xsl:element name="a">
	<xsl:attribute name="style">color:blue; text-decoration:none; 
font-size:0.7em;</xsl:attribute>
	<xsl:attribute name="href"><xsl:value-of 
select="concat($link2conspect,'#',$subsecnumber.index)"/></xsl:attribute>(&#187;
K)</xsl:element>
</xsl:if>
</p>


<xsl:apply-templates>
	<xsl:with-param name="sectionanchor" select="$subsecnumber.index" />
	<xsl:with-param name="secnumber" select="$secnumber" />
</xsl:apply-templates>

</xsl:template>


<xsl:template  match="CommentHead">
<xsl:element name="a"><!-- anchor for structure -->
<xsl:attribute name="name">CHExcerpt<xsl:number count="CommentHead"
format="1." level="any" />
</xsl:attribute>

<table width="100%" style="empty-cells:show;margin:0; padding:0;">
<tr>	<!-- if we have an node inside, this node indent itself -->
	<td width="75%"><xsl:apply-templates>
				<xsl:with-param name="stylus">inside</xsl:with-param>
			</xsl:apply-templates>
	&#160;</td>
	<td style="padding-left:2em; vertical-align:top;">

	<xsl:if test="string-length($link2structure)!=0">
	<xsl:element name="a">
	<xsl:attribute name="href"><!-- link to structure file -->
		<xsl:value-of select="concat($link2structure,'#CHStructure')" />
		<xsl:number count="CommentHead" format="1." level="any" />
	</xsl:attribute>
	<xsl:attribute name="style">text-decoration:none;font-weight:bold
	</xsl:attribute>
	 <xsl:value-of select="concat('[',@title,']')" />
	</xsl:element>
	</xsl:if>

	<xsl:if test="string-length($link2structure)=0">
	<b><xsl:value-of select="concat('[',@title,']')" /></b>
	</xsl:if>

	</td>
</tr>
</table>

</xsl:element>
</xsl:template>

<xsl:template  match="Conspectus[@style='inclusive']">
	<xsl:apply-templates />
</xsl:template>


</xsl:stylesheet>



